==> nextcloud-14.0.13.zip: nextcloud/apps/workflowengine/l10n/bg.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Тип MIME файл",
    "is" : "е",
    "is not" : "не е",
    "matches" : "съвпадения",
    "does not match" : "не съвпада",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "File name" : "Име на файл",
    "File size (upload)" : "Големина на файл (качване)",
    "less" : "по-малко",
    "less or equals" : "по-малко или равно",
    "greater or equals" : "по-голямо или равно",
    "greater" : "по-голям",
    "File system tag" : "Етикет на файлова система",
    "is tagged with" : "има етикет",
    "is not tagged with" : "няма етикет",
    "Select tag…" : "Изберете етикет...",
    "Request remote address" : "Искане на отдалечен адрес",
    "matches IPv4" : "съвпада IPv4",
    "does not match IPv4" : "не съвпада IPv4",
    "matches IPv6" : "съвпада IPv6",
    "does not match IPv6" : "не съвпада IPv6",
    "Request time" : "Врене ба заявка",
    "between" : "между",
    "not between" : "не между",
    "Start" : "Начало",
    "End" : "Край",
    "Select timezone…" : "Изберете часови пояс...",
    "Request URL" : "URL на заявка",
    "Predefined URLs" : "Предефинирани URL-и",
    "Files WebDAV" : "Файлове WebDAV",
    "Request user agent" : "Потребителски агент на заявка",
    "Sync clients" : "Синхронизиране на клиенти",
    "Android client" : "Android клиент",
    "iOS client" : "iOS клиент",
    "Desktop client" : "Клиент за настолен компютър",
    "User group membership" : "Членство към потребителска група",
    "is member of" : "е член на",
    "is not member of" : "не е член на",
    "Short rule description" : "Кратко описание на правило",
    "Add rule" : "Добави правило",
    "Reset" : "Възстанови",
    "Save" : "Запази",
    "Saving…" : "Запазване...",
    "Saved" : "Запазено",
    "Saving failed:" : "Запазването се провали:",
    "Add rule group" : "Добави група правила",
    "The given operator is invalid" : "Даденият оператор е невалиден",
    "The given regular expression is invalid" : "Даденият израз е невалиден",
    "The given file size is invalid" : "Даденият размер на файла не е валиден",
    "The given tag id is invalid" : "Даденият етикет не е валиден",
    "The given IP range is invalid" : "Даденият IP диапазон е невалиден",
    "The given IP range is not valid for IPv4" : "Даденият IP диапазон не е валиден за IPv4",
    "The given IP range is not valid for IPv6" : "Даденият IP диапазон не е валиден за IPv6",
    "The given time span is invalid" : "Даденият период е невалиден",
    "The given start time is invalid" : "Даденият начален час е невалиден",
    "The given end time is invalid" : "Даденият краен час е невалиден",
    "The given group does not exist" : "Дадената група не съществува",
    "Check %s is invalid or does not exist" : "Проверка %s не е валидна или несъществува",
    "Operation #%s does not exist" : "Операция #%s не съществува",
    "Operation %s does not exist" : "Операция %s не съществува",
    "Operation %s is invalid" : "Операция %s е невалидна",
    "Check %s does not exist" : "Проверка %s не съществува",
    "Check %s is invalid" : "Проверка %s е невалидна",
    "Check #%s does not exist" : "Проверка #%s не съществува",
    "Open documentation" : "Отвори документация",
    "Loading…" : "Зареждане...",
    "Workflow" : "Работен процес"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.3.zip: nextcloud/apps/workflowengine/l10n/bg.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Кратко описание на правило",
    "Add rule" : "Добави правило",
    "Reset" : "Възстанови",
    "Save" : "Запази",
    "Saving…" : "Запазване...",
    "Saved" : "Запазено",
    "Saving failed:" : "Запазването се провали:",
    "Add rule group" : "Добави група правила",
    "File MIME type" : "Тип MIME файл",
    "is" : "е",
    "is not" : "не е",
    "matches" : "съвпадения",
    "does not match" : "не съвпада",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "File name" : "Име на файл",
    "File size (upload)" : "Големина на файл (качване)",
    "less" : "по-малко",
    "less or equals" : "по-малко или равно",
    "greater or equals" : "по-голямо или равно",
    "greater" : "по-голям",
    "File system tag" : "Етикет на файлова система",
    "is tagged with" : "има етикет",
    "is not tagged with" : "няма етикет",
    "Select tag…" : "Изберете етикет...",
    "Request remote address" : "Искане на отдалечен адрес",
    "matches IPv4" : "съвпада IPv4",
    "does not match IPv4" : "не съвпада IPv4",
    "matches IPv6" : "съвпада IPv6",
    "does not match IPv6" : "не съвпада IPv6",
    "Request time" : "Врене ба заявка",
    "between" : "между",
    "not between" : "не между",
    "Start" : "Начало",
    "End" : "Край",
    "Select timezone…" : "Изберете часови пояс...",
    "Request URL" : "URL на заявка",
    "Predefined URLs" : "Предефинирани URL-и",
    "Files WebDAV" : "Файлове WebDAV",
    "Request user agent" : "Потребителски агент на заявка",
    "Sync clients" : "Синхронизиране на клиенти",
    "Android client" : "Android клиент",
    "iOS client" : "iOS клиент",
    "Desktop client" : "Клиент за настолен компютър",
    "User group membership" : "Членство към потребителска група",
    "is member of" : "е член на",
    "is not member of" : "не е член на",
    "The given operator is invalid" : "Даденият оператор е невалиден",
    "The given regular expression is invalid" : "Даденият израз е невалиден",
    "The given file size is invalid" : "Даденият размер на файла не е валиден",
    "The given tag id is invalid" : "Даденият етикет не е валиден",
    "The given IP range is invalid" : "Даденият IP диапазон е невалиден",
    "The given IP range is not valid for IPv4" : "Даденият IP диапазон не е валиден за IPv4",
    "The given IP range is not valid for IPv6" : "Даденият IP диапазон не е валиден за IPv6",
    "The given time span is invalid" : "Даденият период е невалиден",
    "The given start time is invalid" : "Даденият начален час е невалиден",
    "The given end time is invalid" : "Даденият краен час е невалиден",
    "The given group does not exist" : "Дадената група не съществува",
    "Check %s is invalid or does not exist" : "Проверка %s не е валидна или несъществува",
    "Operation #%s does not exist" : "Операция #%s не съществува",
    "Operation %s does not exist" : "Операция %s не съществува",
    "Operation %s is invalid" : "Операция %s е невалидна",
    "Check %s does not exist" : "Проверка %s не съществува",
    "Check %s is invalid" : "Проверка %s е невалидна",
    "Check #%s does not exist" : "Проверка #%s не съществува",
    "Workflow" : "Работен процес",
    "Open documentation" : "Отвори документация",
    "Loading…" : "Зареждане..."
},
"nplurals=2; plural=(n != 1);");
